import pickle
import matplotlib.pyplot as plt
import scipy.stats as scst
import numpy as np
import arviz as az

RawData = [ ['City',     'Temperature', 'Latitude'], 
            ['Sapporo',     15,             43.1],
            ['Sendai',      20,             38.3],
            ['Niigata',     17,             37.9],
            ['Kanazawa',    18,             36.6],
            ['Tokyo',       24,             35.7], 
            ['Osaka',       22,             34.7],
            ['Fukuoka',     22,             33.6],
            ['Kochi',       24,             33.6],
            ['Kagoshima',   23,             31.6],
            ['Naha',        26,             26.2]
]

ID = []
Y = []
X = []
N = len(RawData) - 1
for i in range(N):
    ID.append(RawData[i + 1][0])
    Y.append(RawData[i + 1][1])
    X.append(RawData[i + 1][2])

for v in zip(ID, Y, X):
    print(v)

with open('infrnc_d.pkl', 'rb') as f:
    infrnc_d = pickle.load(f)
print('Summary...\n', az.summary(infrnc_d))

with open('d_frame.pkl', 'rb') as f:
    d_frame = pickle.load(f)

print('Keys...\n', d_frame.keys())

plt.hist(d_frame['b0'])
plt.title('MCMC sample of b0', fontsize = 20)
plt.xlabel('b0', fontsize = 16)
plt.savefig('Figb0.png')
plt.show()

plt.hist(d_frame['b1'])
plt.title('MCMC sample of b1', fontsize = 20)
plt.xlabel('b1', fontsize = 16)
plt.savefig('Figb1.png')
plt.show()

plt.hist(d_frame['sgm'])
plt.title('MCMC sample of sgm', fontsize = 20)
plt.xlabel('sgm', fontsize = 16)
plt.savefig('Figsgm.png')
plt.show()

r = scst.pearsonr(d_frame['b0'], d_frame['b1'])[0]
print('r = ', r)
plt.xlabel('b0')
plt.ylabel('b1')
plt.title('r = {0:.3f}'.format(r), fontsize = 24)
plt.plot(d_frame['b0'], d_frame['b1'], 'b.')
plt.xlabel('b0', fontsize = 16)
plt.ylabel('b1', fontsize = 16)
plt.savefig('Figb0b1.png')
plt.show()

k_names = [f'mu.{i}' for i in range(1,11)]
print(k_names)
MedPreds = []
for i in range(10):
    MedPreds.append(np.percentile(d_frame[k_names[i]], 50))

plt.xlabel('Data')
plt.ylabel('Prediction')
plt.plot(Y, MedPreds, 'bo')
for nm, y, pred in zip(ID, Y, MedPreds):
    plt.text(y + 0.1, pred + 0.1, nm)
plt.plot([14, 28], [14, 28], 'b-')
plt.savefig('FigPrdctn.png')
plt.show()
