import stan
import pickle
import numpy as np
import arviz as az

RawData = [ ['City',     'Temperature', 'Latitude'], 
            ['Sapporo',     15,             43.1],
            ['Sendai',      20,             38.3],
            ['Niigata',     17,             37.9],
            ['Kanazawa',    18,             36.6],
            ['Tokyo',       24,             35.7], 
            ['Osaka',       22,             34.7],
            ['Fukuoka',     22,             33.6],
            ['Kochi',       24,             33.6],
            ['Kagoshima',   23,             31.6],
            ['Naha',        26,             26.2]
]

ID = []
Y = []
X = []
N = len(RawData) - 1
for i in range(N):
    ID.append(RawData[i + 1][0])
    Y.append(RawData[i + 1][1])
    X.append(RawData[i + 1][2])

for v in zip(ID, Y, X):
    print(v)

Data = {'N': N, 'Y': Y, 'X': X}
with open('Regression.stan', 'r') as f:
    sm = stan.build(f.read(), data = Data)

fit = sm.sample()

print('fit =\n', fit)
infrnc_d = az.from_pystan(posterior = fit, posterior_model = sm )
print('\nSummary =\n', az.summary(infrnc_d))

with open('infrnc_d.pkl', 'wb') as f:
    pickle.dump(infrnc_d, f)

d_frame = fit.to_frame()
print(d_frame.keys())
with open('d_frame.pkl', 'wb') as f:
    pickle.dump(d_frame, f)
